stalker.core.models.Project
===========================

.. inheritance-diagram::
     stalker.core.models.Project
     :parts: 1

.. currentmodule:: stalker.core.models

.. autoclass:: Project
   :show-inheritance:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Project.__init__
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~Project.assets
      ~Project.code
      ~Project.created_by
      ~Project.date_created
      ~Project.date_updated
      ~Project.description
      ~Project.display_width
      ~Project.due_date
      ~Project.duration
      ~Project.fps
      ~Project.image_format
      ~Project.is_stereoscopic
      ~Project.lead
      ~Project.name
      ~Project.nice_name
      ~Project.notes
      ~Project.references
      ~Project.repository
      ~Project.sequences
      ~Project.start_date
      ~Project.status
      ~Project.status_list
      ~Project.structure
      ~Project.tags
      ~Project.tasks
      ~Project.type
      ~Project.updated_by
      ~Project.users
   
   